/**
 * Created by zhulingxiao on 2017/10/18.
 *
 * @方法 fetchData
 * @方法 setScrollTop
 * @数据 data = {
 *  isFetch, //如果正在请求, 设置isFetch = true, 防止多次请求
 *  haveMore //当返回的数据 小于 pagesize， 设置 haveMore = true
 * }
 *
 */
import React from 'react';
import PropTypes from 'prop-types';

const styles = {
    footer:{
        textAlign:'center',
        marginTop:20
    },
    bottomWord:{
        fontSize:14,
        marginTop:5,
        color:'#999'
    }
}

class DropToLoad extends React.PureComponent{

    state = {
        isFetch: false,
        haveMore: true
    }

    componentDidMount(){
        window.addEventListener('scroll', this.loadingMore)
    }

    componentWillUnmount() {
        window.removeEventListener('scroll', this.loadingMore);
    }

    loadingMore = () => {

        //解决scrollTop兼容性
        const scrollTop = document.body.scrollTop + document.documentElement.scrollTop;

        const { isFetch, haveMore } = this.props.data;

        //设置当前滚动位置
        if(this.props.setScrollTop){ this.props.setScrollTop(scrollTop) }

        //如果没有在请求，并且还为加载完所有数据，就能执行请求。
        if(!isFetch && haveMore){

            const distance = document.body.scrollHeight - scrollTop;

            const triggerDistance = this.props.triggerDistance || 20;

            if(distance < document.documentElement.clientHeight + triggerDistance){

                this.props.fetchData()

            }

        }

    }

    render(){

        const { children, data, color, bottomWord, loadingEle } = this.props;
      
        const { haveMore } = data;

        return(

            
            <div>

                {
                    children
                }

                {
                    <div key='icon' style={styles.footer}>

                        {
                            haveMore ?

                                loadingEle ? loadingEle : 'loading...'

                                :

                                <span style={styles.bottomWord}>{bottomWord || '没有更多了...'}</span>
                        }

                    </div>
                }

            </div>

        )

    }

}

DropToLoad.propTypes = {
    triggerDistance:PropTypes.number,
    bottomWord:PropTypes.string,
    setScrollTop:PropTypes.func,
    fetchData:PropTypes.func.isRequired,
    data:PropTypes.object.isRequired,
    loadingEle:PropTypes.element
}

export default DropToLoad